package com.nokia.financeapi.service.car;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.common.exception.BizException;
import com.nokia.financeapi.pojo.dto.CarDataImportDto;
import com.nokia.financeapi.pojo.enums.CarDataImportEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

@Slf4j
@Service
public class CarDataImportService {
    private final CarWeiZhangImportService carWeiZhangImportService;

    public CarDataImportService(CarWeiZhangImportService carWeiZhangImportService) {
        this.carWeiZhangImportService = carWeiZhangImportService;
    }

    public R<Object> dataImport(CarDataImportDto dto, MultipartFile file) {
        try {
            if (file.isEmpty()) {
                return R.error("文件为空");
            }
            if (!StringUtils.endsWithIgnoreCase(file.getOriginalFilename(), ".xlsx")) {
                return R.error("文件格式错误");
            }
            if (CarDataImportEnum.WEI_ZHANG.equals(dto.getId())) {
                carWeiZhangImportService.dataImport(dto, file);
            }
            return R.ok();
        } catch (BizException e) {
            return R.error(e.getMessage());
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return R.error("导入失败");
        }
    }
}
